@@ -91,7 +91,7 @@ def build(self, run_epubcheck: bool, build_kobo: bool, build_kindle: bool, outpu
 		if not self.metadata_dom.xpath("//dc:title"):
 			raise se.InvalidSeEbookException(f"Missing [xml]<dc:title>[/] element in [path][link=file://{self.metadata_file_path}]{self.metadata_file_path}[/][/].")
 
-		output_filename = identifier.replace("https://standardebooks.org/ebooks/", "").replace("/", "_")
+		output_filename = identifier.replace("https://libro.org/ebooks/", "").replace("/", "_")
 		url_author = ""
 		for author in self.metadata_dom.xpath("//dc:creator"):
 			url_author = url_author + se.formatting.make_url_safe(author.inner_xml()) + "_"
@@ -779,7 +779,7 @@ def build(self, run_epubcheck: bool, build_kobo: bool, build_kindle: bool, outpu
 		cover_id = self.metadata_dom.xpath("//item[@properties=\"cover-image\"]/@id")[0].replace(".svg", ".jpg")
 		metadata_xml = regex.sub(r"(<metadata[^>]+?>)", f"\\1\n\t\t<meta content=\"{cover_id}\" name=\"cover\" />", metadata_xml)
 
-		# Add metadata to content.opf indicating this file is a Libro.Org compatibility build
+		# Add metadata to content.opf indicating this file is a Libro.org compatibility build
 		metadata_xml = metadata_xml.replace("<dc:publisher", "<meta property=\"se:transform\">compatibility</meta>\n\t\t<dc:publisher")
 
 		# Add any new MathML images we generated to the manifest
